Description Usage Format Source
East African elephant (Loxodonta africana) biological data from 3,175 field record sheets (in some instances, multiple cases were assigned to a single sheet). The data were recorded from 1965 to 1969 during herd culling designed to mitigate elephant herd overpopulation at multiple environmentally stressed national park sites. The data are unique in several ways: the conditions in which such a large number of elephants were represented are unlikely to be reproduced; the sampling represents natural (albeit stressed) family groups rather than trophies or weak animals (as is generally true in managed environments). From The Ian Parker East African Elephant Data Sheets: A handbook for the transcribed biological data set.
1 |
A data frame with 3306 observations on the following 100 variables.
template_id (Template version): Internal variable indicates REDCap online template version employed by transcriber.
red_cap_id (Record ID): Internal variable, REDCap system number programmatically assigned.
transcriber_id (Transcriber ID): Replaced family and given name of transcriber with an internal numerical variable.
record_url (Record URL): Links to scanned sheet image in UFDC; if scanned on both sides, two URLs are included.
date_collect (Date on original sheet): Original project period spanned 1965-1969. Day/Month/Year format converted to Month/Day/Year.
park Park name where record collected was not a project variable, but added to data set for clarity and sort functionality.
locality Place name or description within park as recorded on data sheet.
herd_comp (Herd composition): May have recorded number of individuals, a set of elephant ID numbers, described ages/sexes in group, etc.
elephant_id (Animal or Elephant ID number): Assigned by original data recorder. Unique within park or subproject, but IDs may be repeated within entire data set.
sex As assigned by original data recorder.
age (Age in years): Age groups generally assigned by data recorder, sometimes corrected by original data sheet compilers. If noted as juvenile, estimated months, description of fetus, etc. notes were transcribed.
notes_header (Transcriber or original recorder notes from header): Regarding animal ID, herd, age, etc.
body_length Total body length): Original in feet and inches or centimeters converted to total inches during transcription.
trunk_length (Trunk length): Recorded in feet and inches if added by hand in margin, transcribers converted units to total inches during transcription (to facilitate automated unit conversion).
crown_rump (Crown-rump length): Original measurement units in feet and inches or centimeters converted to total inches during transcription.
occip_tail (Occiput – tail length): Original measurement units in feet and inches or centimeters converted to total inches during transcription.
occip_basetail (Occiput - base tail): Original measurement units in feet and inches or centimeters converted to total inches during transcription.
tail_length (Tail length): Original measurement units in inches or centimeters converted to total inches during transcription where necessary.
shoulder_hght_str (S. height, st.): Shoulder height, straight original measurement units in feet and inches or centimeters converted to total inches during transcription.
shoulder_hght_curv (S. height, C.): Shoulder height, curved original measurement units in feet and inches 10 or centimeters converted to total inches during transcription.
girth_half (Girth x 1/2): Original measurement units in feet and inches or centimeters converted to tota
tusks_liptip_r (Tusks, lip-tip, Right): Original measurement units in feet and inches or centimeters converted to total inches during transcription.
tusks_liptip_l (Tusks, lip-tip, Left): Original measurement units in feet and inches or centimeters converted to total inches during transcription.
tusks_totlength_r (Tusks, total length, Right): Original measurement units in feet and inches or centimeters converted to total inches during transcription.
tusks_totlength_l (Tusks, total length, Left): Original measurement units in feet and inches or centimeters converted to total inches during transcription.
foreft_diam_r (Forefoot diameter, Right): Original measurement units in feet and inches or centimeters converted to total inches during transcription.
foreft_diam_l (Forefoot diameter: Left): Original measurement units in feet and inches or centimeters converted to total inches during transcription.
hindft_diam_r (Hindfoot diameter: Right): Original measurement units in feet and inches or centimeters converted to total inches during transcription.
hindft_diam_l (Hindfoot diameter: Left): Original measurement units in feet and inches or centimeters converted to total inches during transcription.
foreft_circum_r (Forefoot circumference: Right): Original measurement units in feet and inches or centimeters converted to total inches during transcription.
foreft_circum_l (Forefoot circumference: Left): Original measurement units in feet and inches or centimeters converted to total inches during transcription.
hindft_circum_r (Hindfoot circumference: Right): Original measurement units in feet and inches or centimeters converted to total inches during transcription.
hindft_circum_l (Hindfoot circumference: Left): Original measurement units in feet and inches or centimeters converted to total inches during transcription.
toe_nfore_r (Toenails, number of, fore, right): simple count, ranged from 3-5.
toe_nfore_l (Toenails, number of, fore, left): simple count, ranged from 3-5.
toe_nhind_r (Toenails, number of, hind, right): simple count, ranged from 3-5.
toe_nhind_l (Toenails, number of, hind, left): simple count, ranged from 3-5.
tusk_circum_rlip (Tusk circumference at lip, Right): Original measurement units in feet and inches or centimeters converted to total inches during transcription.
tusk_circum_llip (Tusk circumference at lip, Left): Original measurement units in feet and inches or centimeters converted to total inches during transcription.
notes_body (Notes for body section): Sheet notes on length measurements such as body, trunk, tusks, feet, or number of toes.
hindleg_lwght (Left hind leg, weight, if added by hand): Original measurement units in pounds or kilograms converted to grams during transcription.
stomach_full (Stomach, full): Original measurement units in pounds or kilograms converted to grams during transcription.
stomach_empty (Stomach, empty): Original measurement units in pounds or kilograms converted to grams during transcription.
stomach_fill (Stomach, fill): Original measurement units in pounds converted to grams during transcription.
intestine_full (Intestine, full): Original measurement units in pounds converted to grams during transcription.
intestine_empty (Intestine, empty): Original measurement units in pounds converted to grams during transcription.
intestine_fill (Intestine fill): Original measurement units in pounds converted to grams during transcription.
kidneys_fat_r (Kidneys, + fat, right if separate): Organ weight with fat if recorded separately, otherwise total given for both below. Original measurement units in pounds or grams converted to grams during transcription where necessary.
kidneys_fat_l (Kidneys, + fat, left if separate): Organ weight with fat if recorded separately, otherwise total for both organs. Original measurement units in pounds or grams converted to grams during transcription where necessary.
kidneys_fat_tot (Kidneys, + fat; total if written as single weight). Original measurement units in pounds or grams converted to grams during transcription where necessary.
kidneys_fat_r_2 (Kidneys, - fat; weight, right). Organ weight without fat. Original measurement units in pounds or grams converted to grams during transcription where necessary.
kidneys_fat_l_2 (Kidneys, - fat; weight, left). Organ weight without fat. Original measurement units in pounds or grams converted to grams during transcription where necessary.
kidneys_fat_tot_2 (Kidneys, - fat; total if written as single weight). Original measurement units in pounds or grams converted to grams during transcription where necessary.
temporal_gland_r (Temporal gland, right): Original measurement units in grams; no conversion necessary.
temporal_gland_l (Temporal gland, left): Original measurement units in grams; no conversion necessary.
brain (Brain): Original measurement units in pounds converted to grams during transcription.
adrenals_wght_r (Adrenals, right if separate): Original measurement units in grams; no conversion necessary.
adrenals_wght_l (Adrenals, left if separate): Original measurement units in grams; no conversion necessary.
adrenals_wght_tot (Adrenals; total if written as single weight): Original measurement units in grams; no conversion necessary.
thyroid (Thyroid): Original measurement units in grams; no conversion necessary.
heart_wght (Heart): Original measurement units in pounds converted to grams during transcription.
lungs_trachea (Lungs & trachea): Original measurement units in pounds converted to grams during transcription.
liver_wght (Liver): Original measurement units in pounds converted to grams during transcription.
spleen_wght (Spleen): Original measurement units in pounds converted to grams during transcription.
tusk_wght_r (Tusks, right): Original measurement units in pounds converted to grams during transcription.
tusk_wght_l (Tusks, left): Original measurement units in pounds converted to grams during transcription.
notes_wghts (Transcriber or sheet recorder notes on weights): Notes by recorder or transcriber.
lactating (Lactating): Check or tick mark on original sheet indicated ‘yes’; dash or strike indicated ‘no’; blank indicated ‘no data.’
anestrus (Anestrus): Check or tick mark on original sheet indicated ‘yes’; dash or strike indicated ‘no’; blank indicated ‘no data.’
pregnant (Pregnant): Check or tick mark on original sheet indicated ‘yes’; dash or strike indicated ‘no’; blank indicated ‘no data.’
fetus_sex (Foetus: sex): Sex if fetus present.
fetus_lngth (Foetus: length): Original measurement units in inches, centimeters, or millimeters converted to inches during transcription if necessary..
fetus_wght (Foetus: weight): Original measurement units in pounds or grams converted to grams during transcription if necessary.
fetus_umbilicus (Foetus: umbilicus): Original measurement units in inches or centimeters converted to inches during transcription if necessary.
mammary_gland (Mammary gland): Original measurement units in pounds or grams converted to grams during transcription if necessary.
ovaries_r (Ovaries right): Original measurement units in grams; no conversion necessary.
ovaries_l (Ovaries left): Original measurement units in grams; no conversion necessary.
uterus Organ weight plus accompanying fat. Original measurement units in pounds or grams converted to grams during transcription if necessary.
uterus_2 (Uterus -): Organ weight without fat. Original measurement units in pounds or grams converted to grams during transcription if necessary.
conceptus (Conceptus): Original measurement units in pounds converted to grams during transcription.
placenta (Placenta): Original measurement units in pounds or grams converted to grams during transcription if necessary.
parasites (Parasites, if hand written onto form): notes field.
fetus Original measurement units in pounds or grams converted to grams during transcription if necessary.
sperm_smear (Sperm smear): note field on results of procedure.
testes_r (Testes Right): Original measurement units in grams; no conversion necessary.
testes_l (Testes Left): Original measurement units in grams; no conversion necessary.
sem_vesicles_r (Seminal vesicles Right): Original measurement units in grams; no conversion necessary.
sem_vesicles_l (Seminal vesicles Left): Original measurement units in grams; no conversion necessary.
bulbo_urethr_r (Bulbo-urethral gl. Right): Original measurement units in grams; no conversion necessary.
bulbo_urethr_l (Bulbo-urethral gl. Left): Original measurement units in grams; no conversion necessary.
notes_field_reprod (Record any reproductive notes from data sheet here): Transcribed notes field.
notes_other (Record any other notes not transcribed above from data sheet here): Transcribed notes field.
notes_transc_reprod (Transcribers notes on reproduction section): Notes input by transcriber if issues or questions.
tot_wght (Total weight): Original measurement units in pounds converted to grams.
live_wght (Live weight): Original measurement units in pounds or kilograms converted to grams during transcription.
notes_stomach_content (Record any notes under 'Stomach contents' or any other 'Notes' here): Transcribed notes field.
notes_transcriber (Transcriber notes): Notes input by transcriber if issues or questions.
collector (Collector): Name of data collector recorded if available (Budongo only).
ear_tail_lngth (Ear - tail): Measurement for Budongo cases only. Original measurement units in feet and inches or centimeters converted to total inches during transcription.
aorta_wght (Aorta lbs.): Original measurement units in pounds converted to grams during transcription.
The Ian Parker East African Elephant Data Sheets: A handbook for the transcribed biological data set. 2014. https://ufdc.ufl.edu/IR00004209/00001
See also:
Primary Source https://ufdc.ufl.edu/AA00013409/00001
Finding Guide https://findingaids.uflib.ufl.edu/repositories/2/resources/1440/collection_organization#tree::archival_object_272921
Data collected by Ian Parker and Wildlife Services, Ltd., and donated to the University of Florida by Ian S.C. Parker in 2010. The data were then transcribed by Reboussin, Daniel and Norton, Hannah in 2013.
"The Ian Parker East African Elephant Data Sheets".
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.